==> qtcreator-3.6.1-2-aarch64.pkg.tar.xz: usr/share/qtcreator/qml/qmlpuppet/qml2puppet/instances/componentnodeinstance.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
****************************************************************************/

#ifndef COMPONENTNODEINSTANCE_H
#define COMPONENTNODEINSTANCE_H

#include "objectnodeinstance.h"

QT_BEGIN_NAMESPACE
class QQmlComponent;
QT_END_NAMESPACE

namespace QmlDesigner {
namespace Internal {

class ComponentNodeInstance : public ObjectNodeInstance
{
public:
    typedef QSharedPointer<ComponentNodeInstance> Pointer;
    typedef QWeakPointer<ComponentNodeInstance> WeakPointer;
    ComponentNodeInstance(QQmlComponent *component);
    static Pointer create(QObject *objectToBeWrapped);

    bool hasContent() const override;

    void setNodeSource(const QString &source) override;

private: //function
    QQmlComponent *component() const;

};

} // Internal
} // QmlDesigner

#endif // COMPONENTNODEINSTANCE_H

==> qtcreator-4.5.0-1-aarch64.pkg.tar.xz: usr/share/qtcreator/qml/qmlpuppet/qml2puppet/instances/componentnodeinstance.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "objectnodeinstance.h"

QT_BEGIN_NAMESPACE
class QQmlComponent;
QT_END_NAMESPACE

namespace QmlDesigner {
namespace Internal {

class ComponentNodeInstance : public ObjectNodeInstance
{
public:
    typedef QSharedPointer<ComponentNodeInstance> Pointer;
    typedef QWeakPointer<ComponentNodeInstance> WeakPointer;
    ComponentNodeInstance(QQmlComponent *component);
    static Pointer create(QObject *objectToBeWrapped);

    bool hasContent() const override;

    void setNodeSource(const QString &source) override;

private: //function
    QQmlComponent *component() const;

};

} // Internal
} // QmlDesigner
